# muMLE

Tiny (meta-)modeling framework.

Features:

 * mostly textual concrete syntax
 * meta-modeling & constraint writing
 * conformance checking
 * model transformation primitives (match and rewrite)
 * rule-based model transformation
 * examples included:
    - Class Diagrams (self-conforming)
    - Causal Block Diagrams language
    - Petri Net language
